import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The AWS::Amplify::Domain resource allows you to connect a custom domain to your app.
 */
export declare function getDomain(args: GetDomainArgs, opts?: pulumi.InvokeOptions): Promise<GetDomainResult>;
export interface GetDomainArgs {
    /**
     * ARN for the Domain Association.
     */
    arn: string;
}
export interface GetDomainResult {
    /**
     * ARN for the Domain Association.
     */
    readonly arn?: string;
    /**
     * Sets the branch patterns for automatic subdomain creation.
     */
    readonly autoSubDomainCreationPatterns?: string[];
    /**
     * The required AWS Identity and Access Management (IAMlong) service role for the Amazon Resource Name (ARN) for automatically creating subdomains.
     */
    readonly autoSubDomainIamRole?: string;
    readonly certificate?: outputs.amplify.DomainCertificate;
    /**
     * DNS Record for certificate verification.
     */
    readonly certificateRecord?: string;
    /**
     * Status for the Domain Association.
     */
    readonly domainStatus?: string;
    /**
     * Enables the automated creation of subdomains for branches.
     */
    readonly enableAutoSubDomain?: boolean;
    /**
     * Reason for the current status of the domain.
     */
    readonly statusReason?: string;
    /**
     * The setting for the subdomain.
     */
    readonly subDomainSettings?: outputs.amplify.DomainSubDomainSetting[];
    /**
     * The status of the domain update operation that is currently in progress. The following list describes the valid update states.
     *
     * - **REQUESTING_CERTIFICATE** - The certificate is in the process of being updated.
     * - **PENDING_VERIFICATION** - Indicates that an Amplify managed certificate is in the process of being verified. This occurs during the creation of a custom domain or when a custom domain is updated to use a managed certificate.
     * - **IMPORTING_CUSTOM_CERTIFICATE** - Indicates that an Amplify custom certificate is in the process of being imported. This occurs during the creation of a custom domain or when a custom domain is updated to use a custom certificate.
     * - **PENDING_DEPLOYMENT** - Indicates that the subdomain or certificate changes are being propagated.
     * - **AWAITING_APP_CNAME** - Amplify is waiting for CNAME records corresponding to subdomains to be propagated. If your custom domain is on Route 53, Amplify handles this for you automatically. For more information about custom domains, see [Setting up custom domains](https://docs.aws.amazon.com/amplify/latest/userguide/custom-domains.html) in the *Amplify Hosting User Guide* .
     * - **UPDATE_COMPLETE** - The certificate has been associated with a domain.
     * - **UPDATE_FAILED** - The certificate has failed to be provisioned or associated, and there is no existing active certificate to roll back to.
     */
    readonly updateStatus?: string;
}
/**
 * The AWS::Amplify::Domain resource allows you to connect a custom domain to your app.
 */
export declare function getDomainOutput(args: GetDomainOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDomainResult>;
export interface GetDomainOutputArgs {
    /**
     * ARN for the Domain Association.
     */
    arn: pulumi.Input<string>;
}
