import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The ``AWS::ApiGateway::ApiKey`` resource creates a unique key that you can distribute to clients who are executing API Gateway ``Method`` resources that require an API key. To specify which API key clients must use, map the API key with the ``RestApi`` and ``Stage`` resources that include the methods that require a key.
 */
export declare function getApiKey(args: GetApiKeyArgs, opts?: pulumi.InvokeOptions): Promise<GetApiKeyResult>;
export interface GetApiKeyArgs {
    /**
     * The ID for the API key. For example: `abc123` .
     */
    apiKeyId: string;
}
export interface GetApiKeyResult {
    /**
     * The ID for the API key. For example: `abc123` .
     */
    readonly apiKeyId?: string;
    /**
     * An AWS Marketplace customer identifier, when integrating with the AWS SaaS Marketplace.
     */
    readonly customerId?: string;
    /**
     * The description of the ApiKey.
     */
    readonly description?: string;
    /**
     * Specifies whether the ApiKey can be used by callers.
     */
    readonly enabled?: boolean;
    /**
     * DEPRECATED FOR USAGE PLANS - Specifies stages associated with the API key.
     */
    readonly stageKeys?: outputs.apigateway.ApiKeyStageKey[];
    /**
     * The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The tag key can be up to 128 characters and must not start with `aws:` . The tag value can be up to 256 characters.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * The ``AWS::ApiGateway::ApiKey`` resource creates a unique key that you can distribute to clients who are executing API Gateway ``Method`` resources that require an API key. To specify which API key clients must use, map the API key with the ``RestApi`` and ``Stage`` resources that include the methods that require a key.
 */
export declare function getApiKeyOutput(args: GetApiKeyOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetApiKeyResult>;
export interface GetApiKeyOutputArgs {
    /**
     * The ID for the API key. For example: `abc123` .
     */
    apiKeyId: pulumi.Input<string>;
}
