import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource schema for AppSync Api
 */
export declare function getApi(args: GetApiArgs, opts?: pulumi.InvokeOptions): Promise<GetApiResult>;
export interface GetApiArgs {
    /**
     * The Amazon Resource Name (ARN) of the AppSync Api
     */
    apiArn: string;
}
export interface GetApiResult {
    /**
     * The Amazon Resource Name (ARN) of the AppSync Api
     */
    readonly apiArn?: string;
    /**
     * The unique identifier for the AppSync Api generated by the service
     */
    readonly apiId?: string;
    readonly dns?: outputs.appsync.ApiDnsMap;
    /**
     * Describes the authorization configuration for connections, message publishing, message subscriptions, and logging for an Event API.
     */
    readonly eventConfig?: outputs.appsync.ApiEventConfig;
    /**
     * The name of the `Api` .
     */
    readonly name?: string;
    /**
     * The owner contact information for an API resource.
     *
     * This field accepts any string input with a length of 0 - 256 characters.
     */
    readonly ownerContact?: string;
    /**
     * A set of tags (key-value pairs) for this API.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource schema for AppSync Api
 */
export declare function getApiOutput(args: GetApiOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetApiResult>;
export interface GetApiOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the AppSync Api
     */
    apiArn: pulumi.Input<string>;
}
