import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * An entity that defines the scope of audit evidence collected by AWS Audit Manager.
 */
export declare function getAssessment(args: GetAssessmentArgs, opts?: pulumi.InvokeOptions): Promise<GetAssessmentResult>;
export interface GetAssessmentArgs {
    /**
     * The unique identifier for the assessment.
     */
    assessmentId: string;
}
export interface GetAssessmentResult {
    /**
     * The Amazon Resource Name (ARN) of the assessment.
     */
    readonly arn?: string;
    /**
     * The unique identifier for the assessment.
     */
    readonly assessmentId?: string;
    /**
     * The destination that evidence reports are stored in for the assessment.
     */
    readonly assessmentReportsDestination?: outputs.auditmanager.AssessmentReportsDestination;
    /**
     * Specifies when the assessment was created.
     */
    readonly creationTime?: number;
    /**
     * The list of delegations.
     */
    readonly delegations?: outputs.auditmanager.AssessmentDelegation[];
    /**
     * The list of roles for the specified assessment.
     */
    readonly roles?: outputs.auditmanager.AssessmentRole[];
    /**
     * The wrapper of AWS accounts and services that are in scope for the assessment.
     */
    readonly scope?: outputs.auditmanager.AssessmentScope;
    /**
     * The overall status of the assessment.
     *
     * When you create a new assessment, the initial `Status` value is always `ACTIVE` . When you create an assessment, even if you specify the value as `INACTIVE` , the value overrides to `ACTIVE` .
     *
     * After you create an assessment, you can change the value of the `Status` property at any time. For example, when you want to stop collecting evidence for your assessment, you can change the assessment status to `INACTIVE` .
     */
    readonly status?: enums.auditmanager.AssessmentStatus;
    /**
     * The tags associated with the assessment.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * An entity that defines the scope of audit evidence collected by AWS Audit Manager.
 */
export declare function getAssessmentOutput(args: GetAssessmentOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetAssessmentResult>;
export interface GetAssessmentOutputArgs {
    /**
     * The unique identifier for the assessment.
     */
    assessmentId: pulumi.Input<string>;
}
