import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::Bedrock::Flow Resource Type
 */
export declare function getFlow(args: GetFlowArgs, opts?: pulumi.InvokeOptions): Promise<GetFlowResult>;
export interface GetFlowArgs {
    /**
     * Arn representation of the Flow
     */
    arn: string;
}
export interface GetFlowResult {
    /**
     * Arn representation of the Flow
     */
    readonly arn?: string;
    /**
     * Time Stamp.
     */
    readonly createdAt?: string;
    /**
     * A KMS key ARN
     */
    readonly customerEncryptionKeyArn?: string;
    /**
     * The definition of the nodes and connections between the nodes in the flow.
     */
    readonly definition?: outputs.bedrock.FlowDefinition;
    /**
     * Description of the flow
     */
    readonly description?: string;
    /**
     * ARN of a IAM role
     */
    readonly executionRoleArn?: string;
    /**
     * Identifier for a Flow
     */
    readonly id?: string;
    /**
     * Name for the flow
     */
    readonly name?: string;
    /**
     * The status of the flow. The following statuses are possible:
     *
     * - NotPrepared – The flow has been created or updated, but hasn't been prepared. If you just created the flow, you can't test it. If you updated the flow, the `DRAFT` version won't contain the latest changes for testing. Send a [PrepareFlow](https://docs.aws.amazon.com/bedrock/latest/APIReference/API_agent_PrepareFlow.html) request to package the latest changes into the `DRAFT` version.
     * - Preparing – The flow is being prepared so that the `DRAFT` version contains the latest changes for testing.
     * - Prepared – The flow is prepared and the `DRAFT` version contains the latest changes for testing.
     * - Failed – The last API operation that you invoked on the flow failed. Send a [GetFlow](https://docs.aws.amazon.com/bedrock/latest/APIReference/API_agent_GetFlow.html) request and check the error message in the `validations` field.
     */
    readonly status?: enums.bedrock.FlowStatus;
    /**
     * Metadata that you can assign to a resource as key-value pairs. For more information, see the following resources:
     *
     * - [Tag naming limits and requirements](https://docs.aws.amazon.com/tag-editor/latest/userguide/tagging.html#tag-conventions)
     * - [Tagging best practices](https://docs.aws.amazon.com/tag-editor/latest/userguide/tagging.html#tag-best-practices)
     */
    readonly tags?: {
        [key: string]: string;
    };
    readonly testAliasTags?: {
        [key: string]: string;
    };
    /**
     * Time Stamp.
     */
    readonly updatedAt?: string;
    readonly validations?: outputs.bedrock.FlowValidation[];
    /**
     * Draft Version.
     */
    readonly version?: string;
}
/**
 * Definition of AWS::Bedrock::Flow Resource Type
 */
export declare function getFlowOutput(args: GetFlowOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetFlowResult>;
export interface GetFlowOutputArgs {
    /**
     * Arn representation of the Flow
     */
    arn: pulumi.Input<string>;
}
