import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Definition of AWS::Bedrock::PromptVersion Resource Type
 */
export declare class PromptVersion extends pulumi.CustomResource {
    /**
     * Get an existing PromptVersion resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): PromptVersion;
    /**
     * Returns true if the given object is an instance of PromptVersion.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is PromptVersion;
    /**
     * ARN of a prompt version resource
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Time Stamp.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * A KMS key ARN
     */
    readonly customerEncryptionKeyArn: pulumi.Output<string>;
    /**
     * Name for a variant.
     */
    readonly defaultVariant: pulumi.Output<string>;
    /**
     * Description for a prompt version resource.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Name for a prompt resource.
     */
    readonly name: pulumi.Output<string>;
    /**
     * ARN of a prompt resource possibly with a version
     */
    readonly promptArn: pulumi.Output<string>;
    /**
     * Identifier for a Prompt
     */
    readonly promptId: pulumi.Output<string>;
    /**
     * A map of tags attached to the prompt version and their values.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Time Stamp.
     */
    readonly updatedAt: pulumi.Output<string>;
    /**
     * List of prompt variants
     */
    readonly variants: pulumi.Output<outputs.bedrock.PromptVersionPromptVariant[]>;
    /**
     * Version.
     */
    readonly version: pulumi.Output<string>;
    /**
     * Create a PromptVersion resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: PromptVersionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a PromptVersion resource.
 */
export interface PromptVersionArgs {
    /**
     * Description for a prompt version resource.
     */
    description?: pulumi.Input<string>;
    /**
     * ARN of a prompt resource possibly with a version
     */
    promptArn: pulumi.Input<string>;
    /**
     * A map of tags attached to the prompt version and their values.
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
