import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * A distribution tells CloudFront where you want content to be delivered from, and the details about how to track and manage content delivery.
 */
export declare class Distribution extends pulumi.CustomResource {
    /**
     * Get an existing Distribution resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Distribution;
    /**
     * Returns true if the given object is an instance of Distribution.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Distribution;
    /**
     * The distribution's identifier. For example: `E1U5RQF7T870K0` .
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The distribution's configuration.
     */
    readonly distributionConfig: pulumi.Output<outputs.cloudfront.DistributionConfig>;
    /**
     * The domain name of the resource, such as `d111111abcdef8.cloudfront.net` .
     */
    readonly domainName: pulumi.Output<string>;
    /**
     * A complex type that contains zero or more ``Tag`` elements.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Distribution resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DistributionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Distribution resource.
 */
export interface DistributionArgs {
    /**
     * The distribution's configuration.
     */
    distributionConfig: pulumi.Input<inputs.cloudfront.DistributionConfigArgs>;
    /**
     * A complex type that contains zero or more ``Tag`` elements.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
