import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * The resource schema to create a CodeArtifact domain.
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myCodeArtifactDomain = new aws_native.codeartifact.Domain("myCodeArtifactDomain", {domainName: "my-domain"});
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myCodeArtifactDomain = new aws_native.codeartifact.Domain("myCodeArtifactDomain", {domainName: "my-domain"});
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myCodeArtifactDomain = new aws_native.codeartifact.Domain("myCodeArtifactDomain", {
 *     domainName: "my-domain",
 *     encryptionKey: "arn:aws:kms:us-west-2:123456789012:key/12345678-9abc-def1-2345-6789abcdef12",
 *     permissionsPolicyDocument: {
 *         version: "2012-10-17",
 *         statement: [{
 *             action: [
 *                 "codeartifact:ReadFromRepository",
 *                 "codeartifact:DescribePackageVersion",
 *                 "codeartifact:DescribeRepository",
 *                 "codeartifact:GetPackageVersionReadme",
 *                 "codeartifact:GetRepositoryEndpoint",
 *                 "codeartifact:ListPackageVersionAssets",
 *                 "codeartifact:ListPackageVersionDependencies",
 *                 "codeartifact:ListPackageVersions",
 *                 "codeartifact:ListPackages",
 *                 "codeartifact:ReadFromRepository",
 *             ],
 *             effect: "Allow",
 *             principal: {
 *                 aws: "arn:aws:iam::123456789012:root",
 *             },
 *             resource: "*",
 *         }],
 *     },
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myCodeArtifactDomain = new aws_native.codeartifact.Domain("myCodeArtifactDomain", {
 *     domainName: "my-domain",
 *     encryptionKey: "arn:aws:kms:us-west-2:123456789012:key/12345678-9abc-def1-2345-6789abcdef12",
 *     permissionsPolicyDocument: {
 *         version: "2012-10-17",
 *         statement: [{
 *             action: [
 *                 "codeartifact:ReadFromRepository",
 *                 "codeartifact:DescribePackageVersion",
 *                 "codeartifact:DescribeRepository",
 *                 "codeartifact:GetPackageVersionReadme",
 *                 "codeartifact:GetRepositoryEndpoint",
 *                 "codeartifact:ListPackageVersionAssets",
 *                 "codeartifact:ListPackageVersionDependencies",
 *                 "codeartifact:ListPackageVersions",
 *                 "codeartifact:ListPackages",
 *                 "codeartifact:ReadFromRepository",
 *             ],
 *             effect: "Allow",
 *             principal: {
 *                 aws: "arn:aws:iam::123456789012:root",
 *             },
 *             resource: "*",
 *         }],
 *     },
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myCodeArtifactDomain = new aws_native.codeartifact.Domain("myCodeArtifactDomain", {
 *     domainName: "my-domain",
 *     tags: [
 *         {
 *             key: "keyname1",
 *             value: "value1",
 *         },
 *         {
 *             key: "keyname2",
 *             value: "value2",
 *         },
 *     ],
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myCodeArtifactDomain = new aws_native.codeartifact.Domain("myCodeArtifactDomain", {
 *     domainName: "my-domain",
 *     tags: [
 *         {
 *             key: "keyname1",
 *             value: "value1",
 *         },
 *         {
 *             key: "keyname2",
 *             value: "value2",
 *         },
 *     ],
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myCodeArtifactDomain = new aws_native.codeartifact.Domain("myCodeArtifactDomain", {domainName: "my-domain"});
 * const myCodeArtifactRepository = new aws_native.codeartifact.Repository("myCodeArtifactRepository", {
 *     repositoryName: "my-repo",
 *     domainName: myCodeArtifactDomain.name,
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myCodeArtifactDomain = new aws_native.codeartifact.Domain("myCodeArtifactDomain", {domainName: "my-domain"});
 * const myCodeArtifactRepository = new aws_native.codeartifact.Repository("myCodeArtifactRepository", {
 *     repositoryName: "my-repo",
 *     domainName: myCodeArtifactDomain.name,
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myCodeArtifactDomain = new aws_native.codeartifact.Domain("myCodeArtifactDomain", {domainName: "my-domain"});
 * const myCodeArtifactUpstreamRepository = new aws_native.codeartifact.Repository("myCodeArtifactUpstreamRepository", {
 *     repositoryName: "my-upstream-repo",
 *     domainName: myCodeArtifactDomain.name,
 *     externalConnections: ["public:npmjs"],
 * });
 * const myCodeArtifactRepository = new aws_native.codeartifact.Repository("myCodeArtifactRepository", {
 *     repositoryName: "my-repo",
 *     domainName: myCodeArtifactDomain.name,
 *     upstreams: [myCodeArtifactUpstreamRepository.name],
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myCodeArtifactDomain = new aws_native.codeartifact.Domain("myCodeArtifactDomain", {domainName: "my-domain"});
 * const myCodeArtifactUpstreamRepository = new aws_native.codeartifact.Repository("myCodeArtifactUpstreamRepository", {
 *     repositoryName: "my-upstream-repo",
 *     domainName: myCodeArtifactDomain.name,
 *     externalConnections: ["public:npmjs"],
 * });
 * const myCodeArtifactRepository = new aws_native.codeartifact.Repository("myCodeArtifactRepository", {
 *     repositoryName: "my-repo",
 *     domainName: myCodeArtifactDomain.name,
 *     upstreams: [myCodeArtifactUpstreamRepository.name],
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myCodeArtifactDomain = new aws_native.codeartifact.Domain("myCodeArtifactDomain", {domainName: "my-domain"});
 * const myCodeArtifactRepository = new aws_native.codeartifact.Repository("myCodeArtifactRepository", {
 *     repositoryName: "my-repo",
 *     domainName: myCodeArtifactDomain.name,
 *     tags: [
 *         {
 *             key: "keyname1",
 *             value: "value1",
 *         },
 *         {
 *             key: "keyname2",
 *             value: "value2",
 *         },
 *     ],
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myCodeArtifactDomain = new aws_native.codeartifact.Domain("myCodeArtifactDomain", {domainName: "my-domain"});
 * const myCodeArtifactRepository = new aws_native.codeartifact.Repository("myCodeArtifactRepository", {
 *     repositoryName: "my-repo",
 *     domainName: myCodeArtifactDomain.name,
 *     tags: [
 *         {
 *             key: "keyname1",
 *             value: "value1",
 *         },
 *         {
 *             key: "keyname2",
 *             value: "value2",
 *         },
 *     ],
 * });
 *
 * ```
 */
export declare class Domain extends pulumi.CustomResource {
    /**
     * Get an existing Domain resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Domain;
    /**
     * Returns true if the given object is an instance of Domain.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Domain;
    /**
     * The ARN of the domain.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The name of the domain.
     */
    readonly domainName: pulumi.Output<string>;
    /**
     * The ARN of an AWS Key Management Service (AWS KMS) key associated with a domain.
     */
    readonly encryptionKey: pulumi.Output<string>;
    /**
     * The name of the domain. This field is used for GetAtt
     */
    readonly name: pulumi.Output<string>;
    /**
     * The 12-digit account ID of the AWS account that owns the domain. This field is used for GetAtt
     */
    readonly owner: pulumi.Output<string>;
    /**
     * The access control resource policy on the provided domain.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::CodeArtifact::Domain` for more information about the expected schema for this property.
     */
    readonly permissionsPolicyDocument: pulumi.Output<any | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Domain resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: DomainArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Domain resource.
 */
export interface DomainArgs {
    /**
     * The name of the domain.
     */
    domainName?: pulumi.Input<string>;
    /**
     * The ARN of an AWS Key Management Service (AWS KMS) key associated with a domain.
     */
    encryptionKey?: pulumi.Input<string>;
    /**
     * The access control resource policy on the provided domain.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::CodeArtifact::Domain` for more information about the expected schema for this property.
     */
    permissionsPolicyDocument?: any;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
