import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * A calculated attribute definition for Customer Profiles
 */
export declare function getCalculatedAttributeDefinition(args: GetCalculatedAttributeDefinitionArgs, opts?: pulumi.InvokeOptions): Promise<GetCalculatedAttributeDefinitionResult>;
export interface GetCalculatedAttributeDefinitionArgs {
    /**
     * The name of an attribute defined in a profile object type.
     */
    calculatedAttributeName: string;
    /**
     * The unique name of the domain.
     */
    domainName: string;
}
export interface GetCalculatedAttributeDefinitionResult {
    /**
     * Mathematical expression and a list of attribute items specified in that expression.
     */
    readonly attributeDetails?: outputs.customerprofiles.CalculatedAttributeDefinitionAttributeDetails;
    /**
     * The conditions including range, object count, and threshold for the calculated attribute.
     */
    readonly conditions?: outputs.customerprofiles.CalculatedAttributeDefinitionConditions;
    /**
     * The timestamp of when the calculated attribute definition was created.
     */
    readonly createdAt?: string;
    /**
     * The description of the calculated attribute.
     */
    readonly description?: string;
    /**
     * The display name of the calculated attribute.
     */
    readonly displayName?: string;
    /**
     * The timestamp of when the calculated attribute definition was most recently edited.
     */
    readonly lastUpdatedAt?: string;
    /**
     * The aggregation operation to perform for the calculated attribute.
     */
    readonly statistic?: enums.customerprofiles.CalculatedAttributeDefinitionStatistic;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * A calculated attribute definition for Customer Profiles
 */
export declare function getCalculatedAttributeDefinitionOutput(args: GetCalculatedAttributeDefinitionOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCalculatedAttributeDefinitionResult>;
export interface GetCalculatedAttributeDefinitionOutputArgs {
    /**
     * The name of an attribute defined in a profile object type.
     */
    calculatedAttributeName: pulumi.Input<string>;
    /**
     * The unique name of the domain.
     */
    domainName: pulumi.Input<string>;
}
