import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource schema for AWS::DataBrew::Project.
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const testDataBrewProject = new aws_native.databrew.Project("testDataBrewProject", {
 *     name: "project-name",
 *     recipeName: "recipe-name",
 *     datasetName: "dataset-name",
 *     roleArn: "arn:aws:iam::12345678910:role/PassRoleAdmin",
 *     sample: {
 *         size: 500,
 *         type: aws_native.databrew.ProjectSampleType.LastN,
 *     },
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myDataBrewProject = new aws_native.databrew.Project("myDataBrewProject", {
 *     name: "test-project",
 *     recipeName: "test-project-recipe",
 *     datasetName: "test-dataset",
 *     roleArn: "arn:aws:iam::1234567891011:role/PassRoleAdmin",
 *     sample: {
 *         size: 500,
 *         type: aws_native.databrew.ProjectSampleType.LastN,
 *     },
 *     tags: [{
 *         key: "key00AtCreate",
 *         value: "value001AtCreate",
 *     }],
 * });
 *
 * ```
 */
export declare class Project extends pulumi.CustomResource {
    /**
     * Get an existing Project resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Project;
    /**
     * Returns true if the given object is an instance of Project.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Project;
    /**
     * Dataset name
     */
    readonly datasetName: pulumi.Output<string>;
    /**
     * Project name
     */
    readonly name: pulumi.Output<string>;
    /**
     * Recipe name
     */
    readonly recipeName: pulumi.Output<string>;
    /**
     * Role arn
     */
    readonly roleArn: pulumi.Output<string>;
    /**
     * Sample
     */
    readonly sample: pulumi.Output<outputs.databrew.ProjectSample | undefined>;
    /**
     * Metadata tags that have been applied to the project.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Project resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ProjectArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Project resource.
 */
export interface ProjectArgs {
    /**
     * Dataset name
     */
    datasetName: pulumi.Input<string>;
    /**
     * Project name
     */
    name?: pulumi.Input<string>;
    /**
     * Recipe name
     */
    recipeName: pulumi.Input<string>;
    /**
     * Role arn
     */
    roleArn: pulumi.Input<string>;
    /**
     * Sample
     */
    sample?: pulumi.Input<inputs.databrew.ProjectSampleArgs>;
    /**
     * Metadata tags that have been applied to the project.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
