import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Definition of AWS::DataZone::EnvironmentActions Resource Type
 */
export declare class EnvironmentActions extends pulumi.CustomResource {
    /**
     * Get an existing EnvironmentActions resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): EnvironmentActions;
    /**
     * Returns true if the given object is an instance of EnvironmentActions.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is EnvironmentActions;
    /**
     * The ID of the Amazon DataZone environment action.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The description of the Amazon DataZone environment action.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The identifier of the Amazon DataZone domain in which the environment is created.
     */
    readonly domainId: pulumi.Output<string>;
    /**
     * The identifier of the Amazon DataZone domain in which the environment would be created.
     */
    readonly domainIdentifier: pulumi.Output<string | undefined>;
    /**
     * The identifier of the Amazon DataZone environment in which the action is taking place
     */
    readonly environmentId: pulumi.Output<string>;
    /**
     * The identifier of the Amazon DataZone environment in which the action is taking place
     */
    readonly environmentIdentifier: pulumi.Output<string | undefined>;
    /**
     * The ID of the Amazon DataZone environment action.
     */
    readonly identifier: pulumi.Output<string | undefined>;
    /**
     * The name of the environment action.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The parameters of the environment action.
     */
    readonly parameters: pulumi.Output<outputs.datazone.EnvironmentActionsAwsConsoleLinkParameters | undefined>;
    /**
     * Create a EnvironmentActions resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: EnvironmentActionsArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a EnvironmentActions resource.
 */
export interface EnvironmentActionsArgs {
    /**
     * The description of the Amazon DataZone environment action.
     */
    description?: pulumi.Input<string>;
    /**
     * The identifier of the Amazon DataZone domain in which the environment would be created.
     */
    domainIdentifier?: pulumi.Input<string>;
    /**
     * The identifier of the Amazon DataZone environment in which the action is taking place
     */
    environmentIdentifier?: pulumi.Input<string>;
    /**
     * The ID of the Amazon DataZone environment action.
     */
    identifier?: pulumi.Input<string>;
    /**
     * The name of the environment action.
     */
    name?: pulumi.Input<string>;
    /**
     * The parameters of the environment action.
     */
    parameters?: pulumi.Input<inputs.datazone.EnvironmentActionsAwsConsoleLinkParametersArgs>;
}
