import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Definition of AWS::DataZone::EnvironmentBlueprintConfiguration Resource Type
 */
export declare class EnvironmentBlueprintConfiguration extends pulumi.CustomResource {
    /**
     * Get an existing EnvironmentBlueprintConfiguration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): EnvironmentBlueprintConfiguration;
    /**
     * Returns true if the given object is an instance of EnvironmentBlueprintConfiguration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is EnvironmentBlueprintConfiguration;
    /**
     * The timestamp of when an environment blueprint was created.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * The identifier of the Amazon DataZone domain in which an environment blueprint exists.
     */
    readonly domainId: pulumi.Output<string>;
    /**
     * The identifier of the Amazon DataZone domain in which an environment blueprint exists.
     */
    readonly domainIdentifier: pulumi.Output<string>;
    /**
     * The enabled AWS Regions specified in a blueprint configuration.
     */
    readonly enabledRegions: pulumi.Output<string[]>;
    /**
     * The identifier of the environment blueprint. This identifier should be used when creating environment profiles.
     */
    readonly environmentBlueprintId: pulumi.Output<string>;
    /**
     * The identifier of the environment blueprint.
     *
     * In the current release, only the following values are supported: `DefaultDataLake` and `DefaultDataWarehouse` .
     */
    readonly environmentBlueprintIdentifier: pulumi.Output<string>;
    /**
     * The environment role permission boundary.
     */
    readonly environmentRolePermissionBoundary: pulumi.Output<string | undefined>;
    /**
     * The ARN of the manage access role.
     */
    readonly manageAccessRoleArn: pulumi.Output<string | undefined>;
    /**
     * The provisioning configuration of a blueprint.
     */
    readonly provisioningConfigurations: pulumi.Output<outputs.datazone.EnvironmentBlueprintConfigurationProvisioningConfigurationProperties[] | undefined>;
    /**
     * The ARN of the provisioning role.
     */
    readonly provisioningRoleArn: pulumi.Output<string | undefined>;
    /**
     * The regional parameters of the environment blueprint.
     */
    readonly regionalParameters: pulumi.Output<outputs.datazone.EnvironmentBlueprintConfigurationRegionalParameter[] | undefined>;
    /**
     * The timestamp of when the environment blueprint was updated.
     */
    readonly updatedAt: pulumi.Output<string>;
    /**
     * Create a EnvironmentBlueprintConfiguration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: EnvironmentBlueprintConfigurationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a EnvironmentBlueprintConfiguration resource.
 */
export interface EnvironmentBlueprintConfigurationArgs {
    /**
     * The identifier of the Amazon DataZone domain in which an environment blueprint exists.
     */
    domainIdentifier: pulumi.Input<string>;
    /**
     * The enabled AWS Regions specified in a blueprint configuration.
     */
    enabledRegions: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The identifier of the environment blueprint.
     *
     * In the current release, only the following values are supported: `DefaultDataLake` and `DefaultDataWarehouse` .
     */
    environmentBlueprintIdentifier: pulumi.Input<string>;
    /**
     * The environment role permission boundary.
     */
    environmentRolePermissionBoundary?: pulumi.Input<string>;
    /**
     * The ARN of the manage access role.
     */
    manageAccessRoleArn?: pulumi.Input<string>;
    /**
     * The provisioning configuration of a blueprint.
     */
    provisioningConfigurations?: pulumi.Input<pulumi.Input<inputs.datazone.EnvironmentBlueprintConfigurationProvisioningConfigurationPropertiesArgs>[]>;
    /**
     * The ARN of the provisioning role.
     */
    provisioningRoleArn?: pulumi.Input<string>;
    /**
     * The regional parameters of the environment blueprint.
     */
    regionalParameters?: pulumi.Input<pulumi.Input<inputs.datazone.EnvironmentBlueprintConfigurationRegionalParameterArgs>[]>;
}
