import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * Group profiles represent groups of Amazon DataZone users. Groups can be manually created, or mapped to Active Directory groups of enterprise customers. In Amazon DataZone, groups serve two purposes. First, a group can map to a team of users in the organizational chart, and thus reduce the administrative work of a Amazon DataZone project owner when there are new employees joining or leaving a team. Second, corporate administrators use Active Directory groups to manage and update user statuses and so Amazon DataZone domain administrators can use these group memberships to implement Amazon DataZone domain policies.
 */
export declare class GroupProfile extends pulumi.CustomResource {
    /**
     * Get an existing GroupProfile resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): GroupProfile;
    /**
     * Returns true if the given object is an instance of GroupProfile.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is GroupProfile;
    /**
     * The ID of the Amazon DataZone group profile.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The identifier of the Amazon DataZone domain in which the group profile is created.
     */
    readonly domainId: pulumi.Output<string>;
    /**
     * The identifier of the Amazon DataZone domain in which the group profile would be created.
     */
    readonly domainIdentifier: pulumi.Output<string>;
    /**
     * The ID of the group.
     */
    readonly groupIdentifier: pulumi.Output<string>;
    /**
     * The group-name of the Group Profile.
     */
    readonly groupName: pulumi.Output<string>;
    /**
     * The status of a group profile.
     */
    readonly status: pulumi.Output<enums.datazone.GroupProfileStatus | undefined>;
    /**
     * Create a GroupProfile resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: GroupProfileArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a GroupProfile resource.
 */
export interface GroupProfileArgs {
    /**
     * The identifier of the Amazon DataZone domain in which the group profile would be created.
     */
    domainIdentifier: pulumi.Input<string>;
    /**
     * The ID of the group.
     */
    groupIdentifier: pulumi.Input<string>;
    /**
     * The status of a group profile.
     */
    status?: pulumi.Input<enums.datazone.GroupProfileStatus>;
}
