import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * Definition of AWS::DataZone::ProjectProfile Resource Type
 */
export declare class ProjectProfile extends pulumi.CustomResource {
    /**
     * Get an existing ProjectProfile resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ProjectProfile;
    /**
     * Returns true if the given object is an instance of ProjectProfile.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ProjectProfile;
    /**
     * The ID of the project profile.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The timestamp of when the project profile was created.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * The user who created the project profile.
     */
    readonly createdBy: pulumi.Output<string>;
    /**
     * The description of the project profile.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The domain ID of the project profile.
     */
    readonly domainId: pulumi.Output<string>;
    readonly domainIdentifier: pulumi.Output<string | undefined>;
    /**
     * The domain unit ID of the project profile.
     */
    readonly domainUnitId: pulumi.Output<string>;
    readonly domainUnitIdentifier: pulumi.Output<string | undefined>;
    readonly identifier: pulumi.Output<string>;
    /**
     * The timestamp at which a project profile was last updated.
     */
    readonly lastUpdatedAt: pulumi.Output<string>;
    /**
     * The name of a project profile.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The status of a project profile.
     */
    readonly status: pulumi.Output<enums.datazone.ProjectProfileStatus | undefined>;
    /**
     * Create a ProjectProfile resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ProjectProfileArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ProjectProfile resource.
 */
export interface ProjectProfileArgs {
    /**
     * The description of the project profile.
     */
    description?: pulumi.Input<string>;
    domainIdentifier?: pulumi.Input<string>;
    domainUnitIdentifier?: pulumi.Input<string>;
    /**
     * The name of a project profile.
     */
    name?: pulumi.Input<string>;
    /**
     * The status of a project profile.
     */
    status?: pulumi.Input<enums.datazone.ProjectProfileStatus>;
}
