import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * This resource schema represents the NotificationChannel resource in the Amazon DevOps Guru.
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myNotificationChannel = new aws_native.devopsguru.NotificationChannel("myNotificationChannel", {config: {
 *     filters: {
 *         messageTypes: [
 *             aws_native.devopsguru.NotificationChannelNotificationMessageType.NewInsight,
 *             aws_native.devopsguru.NotificationChannelNotificationMessageType.ClosedInsight,
 *             aws_native.devopsguru.NotificationChannelNotificationMessageType.SeverityUpgraded,
 *         ],
 *         severities: [
 *             aws_native.devopsguru.NotificationChannelInsightSeverity.Medium,
 *             aws_native.devopsguru.NotificationChannelInsightSeverity.High,
 *         ],
 *     },
 *     sns: {
 *         topicArn: "arn:aws:sns:us-east-1:123456789012:DefaultNotificationChannel",
 *     },
 * }});
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myNotificationChannel1 = new aws_native.devopsguru.NotificationChannel("myNotificationChannel1", {config: {
 *     sns: {
 *         topicArn: "arn:aws:sns:us-east-1:123456789012:DefaultNotificationChannel",
 *     },
 * }});
 * const myNotificationChannel2 = new aws_native.devopsguru.NotificationChannel("myNotificationChannel2", {config: {
 *     sns: {
 *         topicArn: "arn:aws:sns:us-east-1:123456789012:DefaultNotificationChannel2",
 *     },
 * }});
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myNotificationChannel1 = new aws_native.devopsguru.NotificationChannel("myNotificationChannel1", {config: {
 *     sns: {
 *         topicArn: "arn:aws:sns:us-east-1:123456789012:DefaultNotificationChannel",
 *     },
 * }});
 * const myNotificationChannel2 = new aws_native.devopsguru.NotificationChannel("myNotificationChannel2", {config: {
 *     sns: {
 *         topicArn: "arn:aws:sns:us-east-1:123456789012:DefaultNotificationChannel2",
 *     },
 * }});
 *
 * ```
 */
export declare class NotificationChannel extends pulumi.CustomResource {
    /**
     * Get an existing NotificationChannel resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): NotificationChannel;
    /**
     * Returns true if the given object is an instance of NotificationChannel.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is NotificationChannel;
    /**
     * The ID of a notification channel.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * A `NotificationChannelConfig` object that contains information about configured notification channels.
     */
    readonly config: pulumi.Output<outputs.devopsguru.NotificationChannelConfig>;
    /**
     * Create a NotificationChannel resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: NotificationChannelArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a NotificationChannel resource.
 */
export interface NotificationChannelArgs {
    /**
     * A `NotificationChannelConfig` object that contains information about configured notification channels.
     */
    config: pulumi.Input<inputs.devopsguru.NotificationChannelConfigArgs>;
}
