import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * VPC Route Server
 */
export declare class RouteServer extends pulumi.CustomResource {
    /**
     * Get an existing RouteServer resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): RouteServer;
    /**
     * Returns true if the given object is an instance of RouteServer.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is RouteServer;
    /**
     * The Amazon-side ASN of the Route Server.
     */
    readonly amazonSideAsn: pulumi.Output<number>;
    /**
     * The Amazon Resource Name (ARN) of the Route Server.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The ID of the Route Server.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * Whether to enable persistent routes
     */
    readonly persistRoutes: pulumi.Output<enums.ec2.RouteServerPersistRoutes | undefined>;
    /**
     * The duration of persistent routes in minutes
     */
    readonly persistRoutesDuration: pulumi.Output<number | undefined>;
    /**
     * Whether to enable SNS notifications
     */
    readonly snsNotificationsEnabled: pulumi.Output<boolean | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a RouteServer resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: RouteServerArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a RouteServer resource.
 */
export interface RouteServerArgs {
    /**
     * The Amazon-side ASN of the Route Server.
     */
    amazonSideAsn: pulumi.Input<number>;
    /**
     * Whether to enable persistent routes
     */
    persistRoutes?: pulumi.Input<enums.ec2.RouteServerPersistRoutes>;
    /**
     * The duration of persistent routes in minutes
     */
    persistRoutesDuration?: pulumi.Input<number>;
    /**
     * Whether to enable SNS notifications
     */
    snsNotificationsEnabled?: pulumi.Input<boolean>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
