import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * VPC Route Server Endpoint
 */
export declare class RouteServerEndpoint extends pulumi.CustomResource {
    /**
     * Get an existing RouteServerEndpoint resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): RouteServerEndpoint;
    /**
     * Returns true if the given object is an instance of RouteServerEndpoint.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is RouteServerEndpoint;
    /**
     * The Amazon Resource Name (ARN) of the Route Server Endpoint.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The ID of the Route Server Endpoint.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * Elastic Network Interface IP address owned by the Route Server Endpoint
     */
    readonly eniAddress: pulumi.Output<string>;
    /**
     * Elastic Network Interface ID owned by the Route Server Endpoint
     */
    readonly eniId: pulumi.Output<string>;
    /**
     * Route Server ID
     */
    readonly routeServerId: pulumi.Output<string>;
    /**
     * Subnet ID
     */
    readonly subnetId: pulumi.Output<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * VPC ID
     */
    readonly vpcId: pulumi.Output<string>;
    /**
     * Create a RouteServerEndpoint resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: RouteServerEndpointArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a RouteServerEndpoint resource.
 */
export interface RouteServerEndpointArgs {
    /**
     * Route Server ID
     */
    routeServerId: pulumi.Input<string>;
    /**
     * Subnet ID
     */
    subnetId: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
