import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::ElasticBeanstalk::ApplicationVersion
 */
export declare class ApplicationVersion extends pulumi.CustomResource {
    /**
     * Get an existing ApplicationVersion resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ApplicationVersion;
    /**
     * Returns true if the given object is an instance of ApplicationVersion.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ApplicationVersion;
    /**
     * The name of the Elastic Beanstalk application that is associated with this application version.
     */
    readonly applicationName: pulumi.Output<string>;
    readonly awsId: pulumi.Output<string>;
    /**
     * A description of this application version.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The Amazon S3 bucket and key that identify the location of the source bundle for this version.
     */
    readonly sourceBundle: pulumi.Output<outputs.elasticbeanstalk.ApplicationVersionSourceBundle>;
    /**
     * Create a ApplicationVersion resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ApplicationVersionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ApplicationVersion resource.
 */
export interface ApplicationVersionArgs {
    /**
     * The name of the Elastic Beanstalk application that is associated with this application version.
     */
    applicationName: pulumi.Input<string>;
    /**
     * A description of this application version.
     */
    description?: pulumi.Input<string>;
    /**
     * The Amazon S3 bucket and key that identify the location of the source bundle for this version.
     */
    sourceBundle: pulumi.Input<inputs.elasticbeanstalk.ApplicationVersionSourceBundleArgs>;
}
