import * as pulumi from "@pulumi/pulumi";
/**
 * Resource schema for AWS::FIS::TargetAccountConfiguration
 */
export declare class TargetAccountConfiguration extends pulumi.CustomResource {
    /**
     * Get an existing TargetAccountConfiguration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): TargetAccountConfiguration;
    /**
     * Returns true if the given object is an instance of TargetAccountConfiguration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is TargetAccountConfiguration;
    /**
     * The AWS account ID of the target account.
     */
    readonly accountId: pulumi.Output<string>;
    /**
     * The description of the target account.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The ID of the experiment template.
     */
    readonly experimentTemplateId: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of an IAM role for the target account.
     */
    readonly roleArn: pulumi.Output<string>;
    /**
     * Create a TargetAccountConfiguration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: TargetAccountConfigurationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a TargetAccountConfiguration resource.
 */
export interface TargetAccountConfigurationArgs {
    /**
     * The AWS account ID of the target account.
     */
    accountId: pulumi.Input<string>;
    /**
     * The description of the target account.
     */
    description?: pulumi.Input<string>;
    /**
     * The ID of the experiment template.
     */
    experimentTemplateId: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of an IAM role for the target account.
     */
    roleArn: pulumi.Input<string>;
}
