import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Creates an AWS Firewall Manager resource set.
 */
export declare function getResourceSet(args: GetResourceSetArgs, opts?: pulumi.InvokeOptions): Promise<GetResourceSetResult>;
export interface GetResourceSetArgs {
    /**
     * A unique identifier for the resource set. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.
     */
    id: string;
}
export interface GetResourceSetResult {
    /**
     * A description of the resource set.
     */
    readonly description?: string;
    /**
     * A unique identifier for the resource set. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.
     */
    readonly id?: string;
    /**
     * The descriptive name of the resource set. You can't change the name of a resource set after you create it.
     */
    readonly name?: string;
    /**
     * Determines the resources that can be associated to the resource set. Depending on your setting for max results and the number of resource sets, a single call might not return the full list.
     */
    readonly resourceTypeList?: string[];
    readonly resources?: string[];
    readonly tags?: outputs.Tag[];
}
/**
 * Creates an AWS Firewall Manager resource set.
 */
export declare function getResourceSetOutput(args: GetResourceSetOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetResourceSetResult>;
export interface GetResourceSetOutputArgs {
    /**
     * A unique identifier for the resource set. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.
     */
    id: pulumi.Input<string>;
}
