import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::GlobalAccelerator::Accelerator
 */
export declare function getAccelerator(args: GetAcceleratorArgs, opts?: pulumi.InvokeOptions): Promise<GetAcceleratorResult>;
export interface GetAcceleratorArgs {
    /**
     * The Amazon Resource Name (ARN) of the accelerator.
     */
    acceleratorArn: string;
}
export interface GetAcceleratorResult {
    /**
     * The Amazon Resource Name (ARN) of the accelerator.
     */
    readonly acceleratorArn?: string;
    /**
     * The Domain Name System (DNS) name that Global Accelerator creates that points to your accelerator's static IPv4 addresses.
     */
    readonly dnsName?: string;
    /**
     * The Domain Name System (DNS) name that Global Accelerator creates that points to your accelerator's static IPv4 and IPv6 addresses.
     */
    readonly dualStackDnsName?: string;
    /**
     * Indicates whether an accelerator is enabled. The value is true or false.
     */
    readonly enabled?: boolean;
    /**
     * IP Address type.
     */
    readonly ipAddressType?: enums.globalaccelerator.AcceleratorIpAddressType;
    /**
     * The IP addresses from BYOIP Prefix pool.
     */
    readonly ipAddresses?: string[];
    /**
     * The IPv4 addresses assigned to the accelerator.
     */
    readonly ipv4Addresses?: string[];
    /**
     * The IPv6 addresses assigned if the accelerator is dualstack
     */
    readonly ipv6Addresses?: string[];
    /**
     * Name of accelerator.
     */
    readonly name?: string;
    /**
     * Create tags for an accelerator.
     *
     * For more information, see [Tagging](https://docs.aws.amazon.com/global-accelerator/latest/dg/tagging-in-global-accelerator.html) in the *AWS Global Accelerator Developer Guide* .
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource Type definition for AWS::GlobalAccelerator::Accelerator
 */
export declare function getAcceleratorOutput(args: GetAcceleratorOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetAcceleratorResult>;
export interface GetAcceleratorOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the accelerator.
     */
    acceleratorArn: pulumi.Input<string>;
}
