import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::GuardDuty::PublishingDestination.
 */
export declare function getPublishingDestination(args: GetPublishingDestinationArgs, opts?: pulumi.InvokeOptions): Promise<GetPublishingDestinationResult>;
export interface GetPublishingDestinationArgs {
    /**
     * The ID of the GuardDuty detector associated with the publishing destination.
     */
    detectorId: string;
    /**
     * The ID of the publishing destination.
     */
    id: string;
}
export interface GetPublishingDestinationResult {
    /**
     * Contains the Amazon Resource Name (ARN) of the resource to publish to, such as an S3 bucket, and the ARN of the KMS key to use to encrypt published findings.
     */
    readonly destinationProperties?: outputs.guardduty.PublishingDestinationCfnDestinationProperties;
    /**
     * The type of resource for the publishing destination. Currently only Amazon S3 buckets are supported.
     */
    readonly destinationType?: string;
    /**
     * The ID of the publishing destination.
     */
    readonly id?: string;
    /**
     * The time, in epoch millisecond format, at which GuardDuty was first unable to publish findings to the destination.
     */
    readonly publishingFailureStartTimestamp?: string;
    /**
     * The status of the publishing destination.
     */
    readonly status?: string;
    /**
     * Describes a tag.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource Type definition for AWS::GuardDuty::PublishingDestination.
 */
export declare function getPublishingDestinationOutput(args: GetPublishingDestinationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetPublishingDestinationResult>;
export interface GetPublishingDestinationOutputArgs {
    /**
     * The ID of the GuardDuty detector associated with the publishing destination.
     */
    detectorId: pulumi.Input<string>;
    /**
     * The ID of the publishing destination.
     */
    id: pulumi.Input<string>;
}
