import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::IoTAnalytics::Dataset
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const dataset = new aws_native.iotanalytics.Dataset("dataset", {
 *     datasetName: "SimpleSQLDataset",
 *     actions: [{
 *         actionName: "SqlAction",
 *         queryAction: {
 *             sqlQuery: "select * from Datastore",
 *         },
 *     }],
 *     triggers: [{
 *         schedule: {
 *             scheduleExpression: "cron(0 12 * * ? *)",
 *         },
 *     }],
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const dataset = new aws_native.iotanalytics.Dataset("dataset", {
 *     datasetName: "SimpleSQLDataset",
 *     actions: [{
 *         actionName: "SqlAction",
 *         queryAction: {
 *             sqlQuery: "select * from Datastore",
 *         },
 *     }],
 *     triggers: [{
 *         schedule: {
 *             scheduleExpression: "cron(0 12 * * ? *)",
 *         },
 *     }],
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const dataset = new aws_native.iotanalytics.Dataset("dataset", {
 *     datasetName: "ComplexSQLDataset",
 *     actions: [{
 *         actionName: "SqlAction",
 *         queryAction: {
 *             sqlQuery: "select * from Datastore",
 *             filters: [{
 *                 deltaTime: {
 *                     offsetSeconds: 1,
 *                     timeExpression: "timestamp",
 *                 },
 *             }],
 *         },
 *     }],
 *     triggers: [{
 *         schedule: {
 *             scheduleExpression: "cron(0 12 * * ? *)",
 *         },
 *     }],
 *     retentionPeriod: {
 *         unlimited: false,
 *         numberOfDays: 10,
 *     },
 *     tags: [
 *         {
 *             key: "keyname1",
 *             value: "value1",
 *         },
 *         {
 *             key: "keyname2",
 *             value: "value2",
 *         },
 *     ],
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const dataset = new aws_native.iotanalytics.Dataset("dataset", {
 *     datasetName: "ComplexSQLDataset",
 *     actions: [{
 *         actionName: "SqlAction",
 *         queryAction: {
 *             sqlQuery: "select * from Datastore",
 *             filters: [{
 *                 deltaTime: {
 *                     offsetSeconds: 1,
 *                     timeExpression: "timestamp",
 *                 },
 *             }],
 *         },
 *     }],
 *     triggers: [{
 *         schedule: {
 *             scheduleExpression: "cron(0 12 * * ? *)",
 *         },
 *     }],
 *     retentionPeriod: {
 *         unlimited: false,
 *         numberOfDays: 10,
 *     },
 *     tags: [
 *         {
 *             key: "keyname1",
 *             value: "value1",
 *         },
 *         {
 *             key: "keyname2",
 *             value: "value2",
 *         },
 *     ],
 * });
 *
 * ```
 */
export declare class Dataset extends pulumi.CustomResource {
    /**
     * Get an existing Dataset resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Dataset;
    /**
     * Returns true if the given object is an instance of Dataset.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Dataset;
    /**
     * The `DatasetAction` objects that automatically create the dataset contents.
     */
    readonly actions: pulumi.Output<outputs.iotanalytics.DatasetAction[]>;
    readonly awsId: pulumi.Output<string>;
    /**
     * When dataset contents are created they are delivered to destinations specified here.
     */
    readonly contentDeliveryRules: pulumi.Output<outputs.iotanalytics.DatasetContentDeliveryRule[] | undefined>;
    /**
     * The name of the dataset.
     */
    readonly datasetName: pulumi.Output<string | undefined>;
    /**
     * A list of data rules that send notifications to CloudWatch, when data arrives late. To specify `lateDataRules` , the dataset must use a [DeltaTimer](https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DeltaTime.html) filter.
     */
    readonly lateDataRules: pulumi.Output<outputs.iotanalytics.DatasetLateDataRule[] | undefined>;
    /**
     * Optional. How long, in days, message data is kept for the dataset.
     */
    readonly retentionPeriod: pulumi.Output<outputs.iotanalytics.DatasetRetentionPeriod | undefined>;
    /**
     * Metadata which can be used to manage the data set.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) .
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The `DatasetTrigger` objects that specify when the dataset is automatically updated.
     */
    readonly triggers: pulumi.Output<outputs.iotanalytics.DatasetTrigger[] | undefined>;
    /**
     * Optional. How many versions of dataset contents are kept. If not specified or set to null, only the latest version plus the latest succeeded version (if they are different) are kept for the time period specified by the `retentionPeriod` parameter. For more information, see [Keeping Multiple Versions of AWS IoT Analytics datasets](https://docs.aws.amazon.com/iotanalytics/latest/userguide/getting-started.html#aws-iot-analytics-dataset-versions) in the *AWS IoT Analytics User Guide* .
     */
    readonly versioningConfiguration: pulumi.Output<outputs.iotanalytics.DatasetVersioningConfiguration | undefined>;
    /**
     * Create a Dataset resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DatasetArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Dataset resource.
 */
export interface DatasetArgs {
    /**
     * The `DatasetAction` objects that automatically create the dataset contents.
     */
    actions: pulumi.Input<pulumi.Input<inputs.iotanalytics.DatasetActionArgs>[]>;
    /**
     * When dataset contents are created they are delivered to destinations specified here.
     */
    contentDeliveryRules?: pulumi.Input<pulumi.Input<inputs.iotanalytics.DatasetContentDeliveryRuleArgs>[]>;
    /**
     * The name of the dataset.
     */
    datasetName?: pulumi.Input<string>;
    /**
     * A list of data rules that send notifications to CloudWatch, when data arrives late. To specify `lateDataRules` , the dataset must use a [DeltaTimer](https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DeltaTime.html) filter.
     */
    lateDataRules?: pulumi.Input<pulumi.Input<inputs.iotanalytics.DatasetLateDataRuleArgs>[]>;
    /**
     * Optional. How long, in days, message data is kept for the dataset.
     */
    retentionPeriod?: pulumi.Input<inputs.iotanalytics.DatasetRetentionPeriodArgs>;
    /**
     * Metadata which can be used to manage the data set.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) .
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The `DatasetTrigger` objects that specify when the dataset is automatically updated.
     */
    triggers?: pulumi.Input<pulumi.Input<inputs.iotanalytics.DatasetTriggerArgs>[]>;
    /**
     * Optional. How many versions of dataset contents are kept. If not specified or set to null, only the latest version plus the latest succeeded version (if they are different) are kept for the time period specified by the `retentionPeriod` parameter. For more information, see [Keeping Multiple Versions of AWS IoT Analytics datasets](https://docs.aws.amazon.com/iotanalytics/latest/userguide/getting-started.html#aws-iot-analytics-dataset-versions) in the *AWS IoT Analytics User Guide* .
     */
    versioningConfiguration?: pulumi.Input<inputs.iotanalytics.DatasetVersioningConfigurationArgs>;
}
