import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Lightsail::Bucket
 */
export declare class Bucket extends pulumi.CustomResource {
    /**
     * Get an existing Bucket resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Bucket;
    /**
     * Returns true if the given object is an instance of Bucket.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Bucket;
    /**
     * Indicates whether the bundle that is currently applied to a bucket can be changed to another bundle. You can update a bucket's bundle only one time within a monthly AWS billing cycle.
     */
    readonly ableToUpdateBundle: pulumi.Output<boolean>;
    /**
     * An object that describes the access rules for the bucket.
     */
    readonly accessRules: pulumi.Output<outputs.lightsail.BucketAccessRules | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the bucket.
     */
    readonly bucketArn: pulumi.Output<string>;
    /**
     * The name for the bucket.
     */
    readonly bucketName: pulumi.Output<string>;
    /**
     * The ID of the bundle to use for the bucket.
     */
    readonly bundleId: pulumi.Output<string>;
    /**
     * Specifies whether to enable or disable versioning of objects in the bucket.
     */
    readonly objectVersioning: pulumi.Output<boolean | undefined>;
    /**
     * An array of strings to specify the AWS account IDs that can access the bucket.
     */
    readonly readOnlyAccessAccounts: pulumi.Output<string[] | undefined>;
    /**
     * The names of the Lightsail resources for which to set bucket access.
     */
    readonly resourcesReceivingAccess: pulumi.Output<string[] | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The URL of the bucket.
     */
    readonly url: pulumi.Output<string>;
    /**
     * Create a Bucket resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: BucketArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Bucket resource.
 */
export interface BucketArgs {
    /**
     * An object that describes the access rules for the bucket.
     */
    accessRules?: pulumi.Input<inputs.lightsail.BucketAccessRulesArgs>;
    /**
     * The name for the bucket.
     */
    bucketName?: pulumi.Input<string>;
    /**
     * The ID of the bundle to use for the bucket.
     */
    bundleId: pulumi.Input<string>;
    /**
     * Specifies whether to enable or disable versioning of objects in the bucket.
     */
    objectVersioning?: pulumi.Input<boolean>;
    /**
     * An array of strings to specify the AWS account IDs that can access the bucket.
     */
    readOnlyAccessAccounts?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The names of the Lightsail resources for which to set bucket access.
     */
    resourcesReceivingAccess?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
