import * as pulumi from "@pulumi/pulumi";
/**
 * Represents a deployment resource of an AWS Mainframe Modernization (M2) application to a specified environment
 */
export declare class Deployment extends pulumi.CustomResource {
    /**
     * Get an existing Deployment resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Deployment;
    /**
     * Returns true if the given object is an instance of Deployment.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Deployment;
    /**
     * The application ID.
     */
    readonly applicationId: pulumi.Output<string>;
    /**
     * The version number of the application to deploy
     */
    readonly applicationVersion: pulumi.Output<number>;
    /**
     * The deployment ID.
     */
    readonly deploymentId: pulumi.Output<string>;
    /**
     * The environment ID.
     */
    readonly environmentId: pulumi.Output<string>;
    /**
     * The status of the deployment.
     */
    readonly status: pulumi.Output<string>;
    /**
     * Create a Deployment resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DeploymentArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Deployment resource.
 */
export interface DeploymentArgs {
    /**
     * The application ID.
     */
    applicationId: pulumi.Input<string>;
    /**
     * The version number of the application to deploy
     */
    applicationVersion: pulumi.Input<number>;
    /**
     * The environment ID.
     */
    environmentId: pulumi.Input<string>;
}
