import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::MediaLive::Network.
 */
export declare function getNetwork(args: GetNetworkArgs, opts?: pulumi.InvokeOptions): Promise<GetNetworkResult>;
export interface GetNetworkArgs {
    /**
     * The unique ID of the Network.
     */
    id: string;
}
export interface GetNetworkResult {
    /**
     * The ARN of the Network.
     */
    readonly arn?: string;
    readonly associatedClusterIds?: string[];
    /**
     * The unique ID of the Network.
     */
    readonly id?: string;
    /**
     * The list of IP address cidr pools for the network
     */
    readonly ipPools?: outputs.medialive.NetworkIpPool[];
    /**
     * The user-specified name of the Network to be created.
     */
    readonly name?: string;
    /**
     * The routes for the network
     */
    readonly routes?: outputs.medialive.NetworkRoute[];
    /**
     * The current state of the Network.
     */
    readonly state?: enums.medialive.NetworkState;
    /**
     * A collection of key-value pairs.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource schema for AWS::MediaLive::Network.
 */
export declare function getNetworkOutput(args: GetNetworkOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetNetworkResult>;
export interface GetNetworkOutputArgs {
    /**
     * The unique ID of the Network.
     */
    id: pulumi.Input<string>;
}
