import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * The AWS::NetworkManager::Site type describes a site.
 */
export declare class Site extends pulumi.CustomResource {
    /**
     * Get an existing Site resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Site;
    /**
     * Returns true if the given object is an instance of Site.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Site;
    /**
     * The date and time that the device was created.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * The description of the site.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The ID of the global network.
     */
    readonly globalNetworkId: pulumi.Output<string>;
    /**
     * The location of the site.
     */
    readonly location: pulumi.Output<outputs.networkmanager.SiteLocation | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the site.
     */
    readonly siteArn: pulumi.Output<string>;
    /**
     * The ID of the site.
     */
    readonly siteId: pulumi.Output<string>;
    /**
     * The state of the site.
     */
    readonly state: pulumi.Output<string>;
    /**
     * The tags for the site.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Site resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SiteArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Site resource.
 */
export interface SiteArgs {
    /**
     * The description of the site.
     */
    description?: pulumi.Input<string>;
    /**
     * The ID of the global network.
     */
    globalNetworkId: pulumi.Input<string>;
    /**
     * The location of the site.
     */
    location?: pulumi.Input<inputs.networkmanager.SiteLocationArgs>;
    /**
     * The tags for the site.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
