import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * An OpenSearch Serverless index resource
 */
export declare class Index extends pulumi.CustomResource {
    /**
     * Get an existing Index resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Index;
    /**
     * Returns true if the given object is an instance of Index.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Index;
    /**
     * The endpoint for the collection.
     */
    readonly collectionEndpoint: pulumi.Output<string>;
    /**
     * The name of the OpenSearch Serverless index.
     */
    readonly indexName: pulumi.Output<string>;
    /**
     * Index Mappings
     */
    readonly mappings: pulumi.Output<outputs.opensearchserverless.MappingsProperties | undefined>;
    /**
     * Index settings
     */
    readonly settings: pulumi.Output<outputs.opensearchserverless.IndexSettings | undefined>;
    /**
     * The unique identifier for the index.
     */
    readonly uuid: pulumi.Output<string>;
    /**
     * Create a Index resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: IndexArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Index resource.
 */
export interface IndexArgs {
    /**
     * The endpoint for the collection.
     */
    collectionEndpoint: pulumi.Input<string>;
    /**
     * The name of the OpenSearch Serverless index.
     */
    indexName?: pulumi.Input<string>;
    /**
     * Index Mappings
     */
    mappings?: pulumi.Input<inputs.opensearchserverless.MappingsPropertiesArgs>;
    /**
     * Index settings
     */
    settings?: pulumi.Input<inputs.opensearchserverless.IndexSettingsArgs>;
}
