import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * You can use organizational units (OUs) to group accounts together to administer as a single unit. This greatly simplifies the management of your accounts. For example, you can attach a policy-based control to an OU, and all accounts within the OU automatically inherit the policy. You can create multiple OUs within a single organization, and you can create OUs within other OUs. Each OU can contain multiple accounts, and you can move accounts from one OU to another. However, OU names must be unique within a parent OU or root.
 */
export declare function getOrganizationalUnit(args: GetOrganizationalUnitArgs, opts?: pulumi.InvokeOptions): Promise<GetOrganizationalUnitResult>;
export interface GetOrganizationalUnitArgs {
    /**
     * The unique identifier (ID) associated with this OU.
     */
    id: string;
}
export interface GetOrganizationalUnitResult {
    /**
     * The Amazon Resource Name (ARN) of this OU.
     */
    readonly arn?: string;
    /**
     * The unique identifier (ID) associated with this OU.
     */
    readonly id?: string;
    /**
     * The friendly name of this OU.
     */
    readonly name?: string;
    /**
     * A list of tags that you want to attach to the newly created OU.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * You can use organizational units (OUs) to group accounts together to administer as a single unit. This greatly simplifies the management of your accounts. For example, you can attach a policy-based control to an OU, and all accounts within the OU automatically inherit the policy. You can create multiple OUs within a single organization, and you can create OUs within other OUs. Each OU can contain multiple accounts, and you can move accounts from one OU to another. However, OU names must be unique within a parent OU or root.
 */
export declare function getOrganizationalUnitOutput(args: GetOrganizationalUnitOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetOrganizationalUnitResult>;
export interface GetOrganizationalUnitOutputArgs {
    /**
     * The unique identifier (ID) associated with this OU.
     */
    id: pulumi.Input<string>;
}
