import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::QBusiness::Index Resource Type
 */
export declare class Index extends pulumi.CustomResource {
    /**
     * Get an existing Index resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Index;
    /**
     * Returns true if the given object is an instance of Index.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Index;
    /**
     * The identifier of the Amazon Q Business application using the index.
     */
    readonly applicationId: pulumi.Output<string>;
    /**
     * The capacity units you want to provision for your index. You can add and remove capacity to fit your usage needs.
     */
    readonly capacityConfiguration: pulumi.Output<outputs.qbusiness.IndexCapacityConfiguration | undefined>;
    /**
     * The Unix timestamp when the index was created.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * A description for the Amazon Q Business index.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The name of the index.
     */
    readonly displayName: pulumi.Output<string>;
    /**
     * Configuration information for document attributes. Document attributes are metadata or fields associated with your documents. For example, the company department name associated with each document.
     *
     * For more information, see [Understanding document attributes](https://docs.aws.amazon.com/amazonq/latest/business-use-dg/doc-attributes.html) .
     */
    readonly documentAttributeConfigurations: pulumi.Output<outputs.qbusiness.IndexDocumentAttributeConfiguration[] | undefined>;
    /**
     * The Amazon Resource Name (ARN) of an Amazon Q Business index.
     */
    readonly indexArn: pulumi.Output<string>;
    /**
     * The identifier for the index.
     */
    readonly indexId: pulumi.Output<string>;
    readonly indexStatistics: pulumi.Output<outputs.qbusiness.IndexStatistics>;
    /**
     * The current status of the index. When the status is `ACTIVE` , the index is ready.
     */
    readonly status: pulumi.Output<enums.qbusiness.IndexStatus>;
    /**
     * A list of key-value pairs that identify or categorize the index. You can also use tags to help control access to the index. Tag keys and values can consist of Unicode letters, digits, white space, and any of the following symbols: _ . : / = + - @.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The index type that's suitable for your needs. For more information on what's included in each type of index, see [Amazon Q Business tiers](https://docs.aws.amazon.com/amazonq/latest/qbusiness-ug/tiers.html#index-tiers) .
     */
    readonly type: pulumi.Output<enums.qbusiness.IndexType | undefined>;
    /**
     * The Unix timestamp when the index was last updated.
     */
    readonly updatedAt: pulumi.Output<string>;
    /**
     * Create a Index resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: IndexArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Index resource.
 */
export interface IndexArgs {
    /**
     * The identifier of the Amazon Q Business application using the index.
     */
    applicationId: pulumi.Input<string>;
    /**
     * The capacity units you want to provision for your index. You can add and remove capacity to fit your usage needs.
     */
    capacityConfiguration?: pulumi.Input<inputs.qbusiness.IndexCapacityConfigurationArgs>;
    /**
     * A description for the Amazon Q Business index.
     */
    description?: pulumi.Input<string>;
    /**
     * The name of the index.
     */
    displayName: pulumi.Input<string>;
    /**
     * Configuration information for document attributes. Document attributes are metadata or fields associated with your documents. For example, the company department name associated with each document.
     *
     * For more information, see [Understanding document attributes](https://docs.aws.amazon.com/amazonq/latest/business-use-dg/doc-attributes.html) .
     */
    documentAttributeConfigurations?: pulumi.Input<pulumi.Input<inputs.qbusiness.IndexDocumentAttributeConfigurationArgs>[]>;
    /**
     * A list of key-value pairs that identify or categorize the index. You can also use tags to help control access to the index. Tag keys and values can consist of Unicode letters, digits, white space, and any of the following symbols: _ . : / = + - @.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The index type that's suitable for your needs. For more information on what's included in each type of index, see [Amazon Q Business tiers](https://docs.aws.amazon.com/amazonq/latest/qbusiness-ug/tiers.html#index-tiers) .
     */
    type?: pulumi.Input<enums.qbusiness.IndexType>;
}
