import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::QBusiness::WebExperience Resource Type
 */
export declare class WebExperience extends pulumi.CustomResource {
    /**
     * Get an existing WebExperience resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): WebExperience;
    /**
     * Returns true if the given object is an instance of WebExperience.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is WebExperience;
    /**
     * The identifier of the Amazon Q Business web experience.
     */
    readonly applicationId: pulumi.Output<string>;
    /**
     * The container for browser extension configuration for an Amazon Q Business web experience.
     */
    readonly browserExtensionConfiguration: pulumi.Output<outputs.qbusiness.WebExperienceBrowserExtensionConfiguration | undefined>;
    /**
     * The Unix timestamp when the Amazon Q Business application was last updated.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * Contains the configuration information to customize the logo, font, and color of an Amazon Q Business web experience with individual files for each property or a CSS file for them all.
     */
    readonly customizationConfiguration: pulumi.Output<outputs.qbusiness.WebExperienceCustomizationConfiguration | undefined>;
    /**
     * The endpoint URLs for your Amazon Q Business web experience. The URLs are unique and fully hosted by AWS .
     */
    readonly defaultEndpoint: pulumi.Output<string>;
    /**
     * Provides information about the identity provider (IdP) used to authenticate end users of an Amazon Q Business web experience.
     */
    readonly identityProviderConfiguration: pulumi.Output<outputs.qbusiness.WebExperienceIdentityProviderConfiguration0Properties | outputs.qbusiness.WebExperienceIdentityProviderConfiguration1Properties | undefined>;
    /**
     * Sets the website domain origins that are allowed to embed the Amazon Q Business web experience. The *domain origin* refers to the base URL for accessing a website including the protocol ( `http/https` ), the domain name, and the port number (if specified).
     *
     * > You must only submit a *base URL* and not a full path. For example, `https://docs.aws.amazon.com` .
     */
    readonly origins: pulumi.Output<string[] | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the service role attached to your web experience.
     *
     * > You must provide this value if you're using IAM Identity Center to manage end user access to your application. If you're using legacy identity management to manage user access, you don't need to provide this value.
     */
    readonly roleArn: pulumi.Output<string | undefined>;
    /**
     * Determines whether sample prompts are enabled in the web experience for an end user.
     */
    readonly samplePromptsControlMode: pulumi.Output<enums.qbusiness.WebExperienceSamplePromptsControlMode | undefined>;
    /**
     * The status of your Amazon Q Business web experience.
     */
    readonly status: pulumi.Output<enums.qbusiness.WebExperienceStatus>;
    /**
     * A subtitle to personalize your Amazon Q Business web experience.
     */
    readonly subtitle: pulumi.Output<string | undefined>;
    /**
     * A list of key-value pairs that identify or categorize your Amazon Q Business web experience. You can also use tags to help control access to the web experience. Tag keys and values can consist of Unicode letters, digits, white space, and any of the following symbols: _ . : / = + - @.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The title for your Amazon Q Business web experience.
     */
    readonly title: pulumi.Output<string | undefined>;
    /**
     * The Unix timestamp when your Amazon Q Business web experience was updated.
     */
    readonly updatedAt: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of an Amazon Q Business web experience.
     */
    readonly webExperienceArn: pulumi.Output<string>;
    /**
     * The identifier of your Amazon Q Business web experience.
     */
    readonly webExperienceId: pulumi.Output<string>;
    /**
     * A message in an Amazon Q Business web experience.
     */
    readonly welcomeMessage: pulumi.Output<string | undefined>;
    /**
     * Create a WebExperience resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: WebExperienceArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a WebExperience resource.
 */
export interface WebExperienceArgs {
    /**
     * The identifier of the Amazon Q Business web experience.
     */
    applicationId: pulumi.Input<string>;
    /**
     * The container for browser extension configuration for an Amazon Q Business web experience.
     */
    browserExtensionConfiguration?: pulumi.Input<inputs.qbusiness.WebExperienceBrowserExtensionConfigurationArgs>;
    /**
     * Contains the configuration information to customize the logo, font, and color of an Amazon Q Business web experience with individual files for each property or a CSS file for them all.
     */
    customizationConfiguration?: pulumi.Input<inputs.qbusiness.WebExperienceCustomizationConfigurationArgs>;
    /**
     * Provides information about the identity provider (IdP) used to authenticate end users of an Amazon Q Business web experience.
     */
    identityProviderConfiguration?: pulumi.Input<inputs.qbusiness.WebExperienceIdentityProviderConfiguration0PropertiesArgs | inputs.qbusiness.WebExperienceIdentityProviderConfiguration1PropertiesArgs>;
    /**
     * Sets the website domain origins that are allowed to embed the Amazon Q Business web experience. The *domain origin* refers to the base URL for accessing a website including the protocol ( `http/https` ), the domain name, and the port number (if specified).
     *
     * > You must only submit a *base URL* and not a full path. For example, `https://docs.aws.amazon.com` .
     */
    origins?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Amazon Resource Name (ARN) of the service role attached to your web experience.
     *
     * > You must provide this value if you're using IAM Identity Center to manage end user access to your application. If you're using legacy identity management to manage user access, you don't need to provide this value.
     */
    roleArn?: pulumi.Input<string>;
    /**
     * Determines whether sample prompts are enabled in the web experience for an end user.
     */
    samplePromptsControlMode?: pulumi.Input<enums.qbusiness.WebExperienceSamplePromptsControlMode>;
    /**
     * A subtitle to personalize your Amazon Q Business web experience.
     */
    subtitle?: pulumi.Input<string>;
    /**
     * A list of key-value pairs that identify or categorize your Amazon Q Business web experience. You can also use tags to help control access to the web experience. Tag keys and values can consist of Unicode letters, digits, white space, and any of the following symbols: _ . : / = + - @.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The title for your Amazon Q Business web experience.
     */
    title?: pulumi.Input<string>;
    /**
     * A message in an Amazon Q Business web experience.
     */
    welcomeMessage?: pulumi.Input<string>;
}
