import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Creates a new DB shard group for Aurora Limitless Database. You must enable Aurora Limitless Database to create a DB shard group.
 *  Valid for: Aurora DB clusters only
 */
export declare class DbShardGroup extends pulumi.CustomResource {
    /**
     * Get an existing DbShardGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): DbShardGroup;
    /**
     * Returns true if the given object is an instance of DbShardGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DbShardGroup;
    /**
     * Specifies whether to create standby DB shard groups for the DB shard group. Valid values are the following:
     *   +  0 - Creates a DB shard group without a standby DB shard group. This is the default value.
     *   +  1 - Creates a DB shard group with a standby DB shard group in a different Availability Zone (AZ).
     *   +  2 - Creates a DB shard group with two standby DB shard groups in two different AZs.
     */
    readonly computeRedundancy: pulumi.Output<number | undefined>;
    /**
     * The name of the primary DB cluster for the DB shard group.
     */
    readonly dbClusterIdentifier: pulumi.Output<string>;
    /**
     * The name of the DB shard group.
     */
    readonly dbShardGroupIdentifier: pulumi.Output<string | undefined>;
    /**
     * The AWS Region -unique, immutable identifier for the DB shard group.
     */
    readonly dbShardGroupResourceId: pulumi.Output<string>;
    /**
     * This data type represents the information you need to connect to an Amazon RDS DB instance. This data type is used as a response element in the following actions:
     *
     * - `CreateDBInstance`
     * - `DescribeDBInstances`
     * - `DeleteDBInstance`
     *
     * For the data structure that represents Amazon Aurora DB cluster endpoints, see `DBClusterEndpoint` .
     */
    readonly endpoint: pulumi.Output<string>;
    /**
     * The maximum capacity of the DB shard group in Aurora capacity units (ACUs).
     */
    readonly maxAcu: pulumi.Output<number>;
    /**
     * The minimum capacity of the DB shard group in Aurora capacity units (ACUs).
     */
    readonly minAcu: pulumi.Output<number | undefined>;
    /**
     * Specifies whether the DB shard group is publicly accessible.
     *  When the DB shard group is publicly accessible, its Domain Name System (DNS) endpoint resolves to the private IP address from within the DB shard group's virtual private cloud (VPC). It resolves to the public IP address from outside of the DB shard group's VPC. Access to the DB shard group is ultimately controlled by the security group it uses. That public access is not permitted if the security group assigned to the DB shard group doesn't permit it.
     *  When the DB shard group isn't publicly accessible, it is an internal DB shard group with a DNS name that resolves to a private IP address.
     *  Default: The default behavior varies depending on whether ``DBSubnetGroupName`` is specified.
     *  If ``DBSubnetGroupName`` isn't specified, and ``PubliclyAccessible`` isn't specified, the following applies:
     *   +  If the default VPC in the target Region doesn’t have an internet gateway attached to it, the DB shard group is private.
     *   +  If the default VPC in the target Region has an internet gateway attached to it, the DB shard group is public.
     *
     *  If ``DBSubnetGroupName`` is specified, and ``PubliclyAccessible`` isn't specified, the following applies:
     *   +  If the subnets are part of a VPC that doesn’t have an internet gateway attached to it, the DB shard group is private.
     *   +  If the subnets are part of a VPC that has an internet gateway attached to it, the DB shard group is public.
     */
    readonly publiclyAccessible: pulumi.Output<boolean | undefined>;
    /**
     * An optional set of key-value pairs to associate arbitrary data of your choosing with the DB shard group.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a DbShardGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DbShardGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a DbShardGroup resource.
 */
export interface DbShardGroupArgs {
    /**
     * Specifies whether to create standby DB shard groups for the DB shard group. Valid values are the following:
     *   +  0 - Creates a DB shard group without a standby DB shard group. This is the default value.
     *   +  1 - Creates a DB shard group with a standby DB shard group in a different Availability Zone (AZ).
     *   +  2 - Creates a DB shard group with two standby DB shard groups in two different AZs.
     */
    computeRedundancy?: pulumi.Input<number>;
    /**
     * The name of the primary DB cluster for the DB shard group.
     */
    dbClusterIdentifier: pulumi.Input<string>;
    /**
     * The name of the DB shard group.
     */
    dbShardGroupIdentifier?: pulumi.Input<string>;
    /**
     * The maximum capacity of the DB shard group in Aurora capacity units (ACUs).
     */
    maxAcu: pulumi.Input<number>;
    /**
     * The minimum capacity of the DB shard group in Aurora capacity units (ACUs).
     */
    minAcu?: pulumi.Input<number>;
    /**
     * Specifies whether the DB shard group is publicly accessible.
     *  When the DB shard group is publicly accessible, its Domain Name System (DNS) endpoint resolves to the private IP address from within the DB shard group's virtual private cloud (VPC). It resolves to the public IP address from outside of the DB shard group's VPC. Access to the DB shard group is ultimately controlled by the security group it uses. That public access is not permitted if the security group assigned to the DB shard group doesn't permit it.
     *  When the DB shard group isn't publicly accessible, it is an internal DB shard group with a DNS name that resolves to a private IP address.
     *  Default: The default behavior varies depending on whether ``DBSubnetGroupName`` is specified.
     *  If ``DBSubnetGroupName`` isn't specified, and ``PubliclyAccessible`` isn't specified, the following applies:
     *   +  If the default VPC in the target Region doesn’t have an internet gateway attached to it, the DB shard group is private.
     *   +  If the default VPC in the target Region has an internet gateway attached to it, the DB shard group is public.
     *
     *  If ``DBSubnetGroupName`` is specified, and ``PubliclyAccessible`` isn't specified, the following applies:
     *   +  If the subnets are part of a VPC that doesn’t have an internet gateway attached to it, the DB shard group is private.
     *   +  If the subnets are part of a VPC that has an internet gateway attached to it, the DB shard group is public.
     */
    publiclyAccessible?: pulumi.Input<boolean>;
    /**
     * An optional set of key-value pairs to associate arbitrary data of your choosing with the DB shard group.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
