import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::Route53Resolver::FirewallRuleGroupAssociation.
 */
export declare class FirewallRuleGroupAssociation extends pulumi.CustomResource {
    /**
     * Get an existing FirewallRuleGroupAssociation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): FirewallRuleGroupAssociation;
    /**
     * Returns true if the given object is an instance of FirewallRuleGroupAssociation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is FirewallRuleGroupAssociation;
    /**
     * Arn
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Id
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * Rfc3339TimeString
     */
    readonly creationTime: pulumi.Output<string>;
    /**
     * The id of the creator request.
     */
    readonly creatorRequestId: pulumi.Output<string>;
    /**
     * FirewallRuleGroupId
     */
    readonly firewallRuleGroupId: pulumi.Output<string>;
    /**
     * ServicePrincipal
     */
    readonly managedOwnerName: pulumi.Output<string>;
    /**
     * Rfc3339TimeString
     */
    readonly modificationTime: pulumi.Output<string>;
    /**
     * MutationProtectionStatus
     */
    readonly mutationProtection: pulumi.Output<enums.route53resolver.FirewallRuleGroupAssociationMutationProtection | undefined>;
    /**
     * FirewallRuleGroupAssociationName
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * Priority
     */
    readonly priority: pulumi.Output<number>;
    /**
     * ResolverFirewallRuleGroupAssociation, possible values are COMPLETE, DELETING, UPDATING, and INACTIVE_OWNER_ACCOUNT_CLOSED.
     */
    readonly status: pulumi.Output<enums.route53resolver.FirewallRuleGroupAssociationStatus>;
    /**
     * FirewallDomainListAssociationStatus
     */
    readonly statusMessage: pulumi.Output<string>;
    /**
     * Tags
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * VpcId
     */
    readonly vpcId: pulumi.Output<string>;
    /**
     * Create a FirewallRuleGroupAssociation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: FirewallRuleGroupAssociationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a FirewallRuleGroupAssociation resource.
 */
export interface FirewallRuleGroupAssociationArgs {
    /**
     * FirewallRuleGroupId
     */
    firewallRuleGroupId: pulumi.Input<string>;
    /**
     * MutationProtectionStatus
     */
    mutationProtection?: pulumi.Input<enums.route53resolver.FirewallRuleGroupAssociationMutationProtection>;
    /**
     * FirewallRuleGroupAssociationName
     */
    name?: pulumi.Input<string>;
    /**
     * Priority
     */
    priority: pulumi.Input<number>;
    /**
     * Tags
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * VpcId
     */
    vpcId: pulumi.Input<string>;
}
