import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * The ``AWS::SecurityHub::DelegatedAdmin`` resource designates the delegated ASHlong administrator account for an organization. You must enable the integration between ASH and AOlong before you can designate a delegated ASH administrator. Only the management account for an organization can designate the delegated ASH administrator account. For more information, see [Designating the delegated administrator](https://docs.aws.amazon.com/securityhub/latest/userguide/designate-orgs-admin-account.html#designate-admin-instructions) in the *User Guide*.
 *  To change the delegated administrator account, remove the current delegated administrator account, and then designate the new account.
 *  To designate multiple delegated administrators in different organizations and AWS-Regions, we recommend using [mappings](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/mappings-section-structure.html).
 *  Tags aren't supported for this resource.
 */
export declare function getDelegatedAdmin(args: GetDelegatedAdminArgs, opts?: pulumi.InvokeOptions): Promise<GetDelegatedAdminResult>;
export interface GetDelegatedAdminArgs {
    /**
     * The ID of the delegated Security Hub administrator account, in the format of `accountID/Region` .
     */
    delegatedAdminIdentifier: string;
}
export interface GetDelegatedAdminResult {
    /**
     * The ID of the delegated Security Hub administrator account, in the format of `accountID/Region` .
     */
    readonly delegatedAdminIdentifier?: string;
    /**
     * Whether the delegated Security Hub administrator is set for the organization.
     */
    readonly status?: enums.securityhub.DelegatedAdminStatus;
}
/**
 * The ``AWS::SecurityHub::DelegatedAdmin`` resource designates the delegated ASHlong administrator account for an organization. You must enable the integration between ASH and AOlong before you can designate a delegated ASH administrator. Only the management account for an organization can designate the delegated ASH administrator account. For more information, see [Designating the delegated administrator](https://docs.aws.amazon.com/securityhub/latest/userguide/designate-orgs-admin-account.html#designate-admin-instructions) in the *User Guide*.
 *  To change the delegated administrator account, remove the current delegated administrator account, and then designate the new account.
 *  To designate multiple delegated administrators in different organizations and AWS-Regions, we recommend using [mappings](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/mappings-section-structure.html).
 *  Tags aren't supported for this resource.
 */
export declare function getDelegatedAdminOutput(args: GetDelegatedAdminOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDelegatedAdminResult>;
export interface GetDelegatedAdminOutputArgs {
    /**
     * The ID of the delegated Security Hub administrator account, in the format of `accountID/Region` .
     */
    delegatedAdminIdentifier: pulumi.Input<string>;
}
