import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * A grouping of protected resources so they can be handled as a collective. This resource grouping improves the accuracy of detection and reduces false positives.
 */
export declare function getProtectionGroup(args: GetProtectionGroupArgs, opts?: pulumi.InvokeOptions): Promise<GetProtectionGroupResult>;
export interface GetProtectionGroupArgs {
    /**
     * The ARN (Amazon Resource Name) of the protection group.
     */
    protectionGroupArn: string;
}
export interface GetProtectionGroupResult {
    /**
     * Defines how AWS Shield combines resource data for the group in order to detect, mitigate, and report events.
     * * Sum - Use the total traffic across the group. This is a good choice for most cases. Examples include Elastic IP addresses for EC2 instances that scale manually or automatically.
     * * Mean - Use the average of the traffic across the group. This is a good choice for resources that share traffic uniformly. Examples include accelerators and load balancers.
     * * Max - Use the highest traffic from each resource. This is useful for resources that don't share traffic and for resources that share that traffic in a non-uniform way. Examples include Amazon CloudFront and origin resources for CloudFront distributions.
     */
    readonly aggregation?: enums.shield.ProtectionGroupAggregation;
    /**
     * The Amazon Resource Names (ARNs) of the resources to include in the protection group. You must set this when you set `Pattern` to `ARBITRARY` and you must not set it for any other `Pattern` setting.
     */
    readonly members?: string[];
    /**
     * The criteria to use to choose the protected resources for inclusion in the group. You can include all resources that have protections, provide a list of resource Amazon Resource Names (ARNs), or include all resources of a specified resource type.
     */
    readonly pattern?: enums.shield.ProtectionGroupPattern;
    /**
     * The ARN (Amazon Resource Name) of the protection group.
     */
    readonly protectionGroupArn?: string;
    /**
     * The resource type to include in the protection group. All protected resources of this type are included in the protection group. Newly protected resources of this type are automatically added to the group. You must set this when you set `Pattern` to `BY_RESOURCE_TYPE` and you must not set it for any other `Pattern` setting.
     */
    readonly resourceType?: enums.shield.ProtectionGroupResourceType;
    /**
     * One or more tag key-value pairs for the Protection object.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * A grouping of protected resources so they can be handled as a collective. This resource grouping improves the accuracy of detection and reduces false positives.
 */
export declare function getProtectionGroupOutput(args: GetProtectionGroupOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetProtectionGroupResult>;
export interface GetProtectionGroupOutputArgs {
    /**
     * The ARN (Amazon Resource Name) of the protection group.
     */
    protectionGroupArn: pulumi.Input<string>;
}
