import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * The AWS::SSM::Document resource is an SSM document in AWS Systems Manager that defines the actions that Systems Manager performs, which can be used to set up and run commands on your instances.
 */
export declare function getDocument(args: GetDocumentArgs, opts?: pulumi.InvokeOptions): Promise<GetDocumentResult>;
export interface GetDocumentArgs {
    /**
     * A name for the Systems Manager document.
     */
    name: string;
}
export interface GetDocumentResult {
    /**
     * The content for the Systems Manager document in JSON, YAML or String format.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::SSM::Document` for more information about the expected schema for this property.
     */
    readonly content?: any;
    /**
     * Specify the document format for the request. The document format can be either JSON or YAML. JSON is the default format.
     */
    readonly documentFormat?: enums.ssm.DocumentFormat;
    /**
     * A list of SSM documents required by a document. For example, an ApplicationConfiguration document requires an ApplicationConfigurationSchema document.
     */
    readonly requires?: outputs.ssm.DocumentRequires[];
    /**
     * Optional metadata that you assign to a resource. Tags enable you to categorize a resource in different ways, such as by purpose, owner, or environment.
     */
    readonly tags?: outputs.Tag[];
    /**
     * Specify a target type to define the kinds of resources the document can run on.
     */
    readonly targetType?: string;
    /**
     * An optional field specifying the version of the artifact you are creating with the document. This value is unique across all versions of a document, and cannot be changed.
     */
    readonly versionName?: string;
}
/**
 * The AWS::SSM::Document resource is an SSM document in AWS Systems Manager that defines the actions that Systems Manager performs, which can be used to set up and run commands on your instances.
 */
export declare function getDocumentOutput(args: GetDocumentOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDocumentResult>;
export interface GetDocumentOutputArgs {
    /**
     * A name for the Systems Manager document.
     */
    name: pulumi.Input<string>;
}
