import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource schema for StateMachine
 */
export declare function getStateMachine(args: GetStateMachineArgs, opts?: pulumi.InvokeOptions): Promise<GetStateMachineResult>;
export interface GetStateMachineArgs {
    /**
     * Returns the ARN of the resource.
     */
    arn: string;
}
export interface GetStateMachineResult {
    /**
     * Returns the ARN of the resource.
     */
    readonly arn?: string;
    /**
     * The Amazon States Language definition of the state machine. The state machine definition must be in JSON. See [Amazon States Language](https://docs.aws.amazon.com/step-functions/latest/dg/concepts-amazon-states-language.html) .
     */
    readonly definitionString?: string;
    /**
     * Encryption configuration for the state machine.
     */
    readonly encryptionConfiguration?: outputs.stepfunctions.StateMachineEncryptionConfiguration;
    /**
     * Defines what execution history events are logged and where they are logged.
     *
     * > By default, the `level` is set to `OFF` . For more information see [Log Levels](https://docs.aws.amazon.com/step-functions/latest/dg/cloudwatch-log-level.html) in the AWS Step Functions User Guide.
     */
    readonly loggingConfiguration?: outputs.stepfunctions.StateMachineLoggingConfiguration;
    /**
     * Returns the name of the state machine. For example:
     *
     * `{ "Fn::GetAtt": ["MyStateMachine", "Name"] }`
     *
     * Returns the name of your state machine:
     *
     * `HelloWorld-StateMachine`
     *
     * If you did not specify the name it will be similar to the following:
     *
     * `MyStateMachine-1234abcdefgh`
     *
     * For more information about using `Fn::GetAtt` , see [Fn::GetAtt](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/intrinsic-function-reference-getatt.html) .
     */
    readonly name?: string;
    /**
     * The Amazon Resource Name (ARN) of the IAM role to use for this state machine.
     */
    readonly roleArn?: string;
    /**
     * Identifier for a state machine revision, which is an immutable, read-only snapshot of a state machine’s definition and configuration.
     */
    readonly stateMachineRevisionId?: string;
    /**
     * The list of tags to add to a resource.
     *
     * Tags may only contain Unicode letters, digits, white space, or these symbols: `_ . : / = + - @` .
     */
    readonly tags?: outputs.Tag[];
    /**
     * Selects whether or not the state machine's AWS X-Ray tracing is enabled.
     */
    readonly tracingConfiguration?: outputs.stepfunctions.StateMachineTracingConfiguration;
}
/**
 * Resource schema for StateMachine
 */
export declare function getStateMachineOutput(args: GetStateMachineOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetStateMachineResult>;
export interface GetStateMachineOutputArgs {
    /**
     * Returns the ARN of the resource.
     */
    arn: pulumi.Input<string>;
}
