import * as pulumi from "@pulumi/pulumi";
/**
 * Definition of AWS::Wisdom::AIPromptVersion Resource Type
 */
export declare class AiPromptVersion extends pulumi.CustomResource {
    /**
     * Get an existing AiPromptVersion resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): AiPromptVersion;
    /**
     * Returns true if the given object is an instance of AiPromptVersion.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AiPromptVersion;
    /**
     * The ARN of the AI prompt.
     */
    readonly aiPromptArn: pulumi.Output<string>;
    /**
     * The identifier of the Amazon Q in Connect AI prompt.
     */
    readonly aiPromptId: pulumi.Output<string>;
    readonly aiPromptVersionId: pulumi.Output<string>;
    readonly assistantArn: pulumi.Output<string>;
    /**
     * The identifier of the Amazon Q in Connect assistant. Can be either the ID or the ARN. URLs cannot contain the ARN.
     */
    readonly assistantId: pulumi.Output<string>;
    /**
     * The time the AI Prompt version was last modified in seconds.
     */
    readonly modifiedTimeSeconds: pulumi.Output<number | undefined>;
    /**
     * The version number for this AI Prompt version.
     */
    readonly versionNumber: pulumi.Output<number>;
    /**
     * Create a AiPromptVersion resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AiPromptVersionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a AiPromptVersion resource.
 */
export interface AiPromptVersionArgs {
    /**
     * The identifier of the Amazon Q in Connect AI prompt.
     */
    aiPromptId: pulumi.Input<string>;
    /**
     * The identifier of the Amazon Q in Connect assistant. Can be either the ID or the ARN. URLs cannot contain the ARN.
     */
    assistantId: pulumi.Input<string>;
    /**
     * The time the AI Prompt version was last modified in seconds.
     */
    modifiedTimeSeconds?: pulumi.Input<number>;
}
