import * as pulumi from "@pulumi/pulumi";
/**
 * A version for the specified customer-managed message template within the specified knowledge base.
 */
export declare class MessageTemplateVersion extends pulumi.CustomResource {
    /**
     * Get an existing MessageTemplateVersion resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): MessageTemplateVersion;
    /**
     * Returns true if the given object is an instance of MessageTemplateVersion.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is MessageTemplateVersion;
    /**
     * The unqualified Amazon Resource Name (ARN) of the message template.
     */
    readonly messageTemplateArn: pulumi.Output<string>;
    /**
     * The content SHA256 of the message template.
     */
    readonly messageTemplateContentSha256: pulumi.Output<string | undefined>;
    /**
     * The unqualified Amazon Resource Name (ARN) of the message template version.
     */
    readonly messageTemplateVersionArn: pulumi.Output<string>;
    /**
     * Current version number of the message template.
     */
    readonly messageTemplateVersionNumber: pulumi.Output<number>;
    /**
     * Create a MessageTemplateVersion resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: MessageTemplateVersionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a MessageTemplateVersion resource.
 */
export interface MessageTemplateVersionArgs {
    /**
     * The unqualified Amazon Resource Name (ARN) of the message template.
     */
    messageTemplateArn: pulumi.Input<string>;
    /**
     * The content SHA256 of the message template.
     */
    messageTemplateContentSha256?: pulumi.Input<string>;
}
